@@ -33,4 +33,6 @@ from .date_helpers import years_after
 from .date_helpers import years_since
 
 from .dict_helpers import make_dict_path
-from .dict_helpers import set_dict_path
\ No newline at end of file
+from .dict_helpers import set_dict_path
+from .dict_helpers import get_dict_path
+from .dict_helpers import deep_copy_dict_no_overwrite
\ No newline at end of file
